@@ -37,7 +37,7 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = '0.02_01';
+our $VERSION = '0.02';
 
 
 # Preloaded methods go here.
@@ -188,14 +188,14 @@ sub add {
 sub get_range {
 	my ($self, $prefix, $plen) = @_;
 
-	my ($type, $addr_bin) = unpack("CB*", $prefix);
+	my ($type, $addr_bin) = unpack("Cb*", $prefix);
 
 	my $addrlen = ($type == AF_INET6) ? 128 : 32;
 	
 	my $first = substr($addr_bin, 0, $plen) . "0"x($addrlen - $plen);
 	my $last = substr($addr_bin, 0, $plen) . "1"x($addrlen - $plen);
 
-	return (pack("CB*", $type, $first).V0, pack("CB*", $type, $last).VF);
+	return (pack("Cb*", $type, $first).V0, pack("Cb*", $type, $last).VF);
 }
 	
 =head2 rebuild - Rebuild Prefix Database
@@ -216,11 +216,11 @@ sub rebuild {
 	my ($self, $addr) = @_;
 
 	# initalize whole range as undef
-	$self->{DB}->put(pack('C', AF_INET6).inet_pton(AF_INET6, '::').V0, '');
-	$self->{DB}->put(pack('C', AF_INET6).inet_pton(AF_INET6, 'FFFF:FFFF:FFFF:FFFF:FFFF:FFFF:FFFF:FFFF').VF, '');
+	$self->{DB}->put(pack('C', AF_INET6).inet_pton(AF_INET6, '::').V0, undef);
+	$self->{DB}->put(pack('C', AF_INET6).inet_pton(AF_INET6, 'FFFF:FFFF:FFFF:FFFF:FFFF:FFFF:FFFF:FFFF').VF, undef);
 
-	$self->{DB}->put(pack('C', AF_INET).inet_pton(AF_INET, '0.0.0.0').V0, '');
-	$self->{DB}->put(pack('C', AF_INET).inet_pton(AF_INET, '255.255.255.255').VF, '');
+	$self->{DB}->put(pack('C', AF_INET).inet_pton(AF_INET, '0.0.0.0').V0, undef);
+	$self->{DB}->put(pack('C', AF_INET).inet_pton(AF_INET, '255.255.255.255').VF, undef);
 
 	foreach my $plen ( sort { $a <=> $b } keys %{$self->{PREFIXES}} ) {
 		while ( my ($prefix, $value) = each ( %{$self->{PREFIXES}->{$plen}} ) ) {
@@ -269,9 +269,7 @@ sub lookup {
 
 	return undef if (! defined($addr_bin) );
 
-	my $result = $self->_lookup_raw($addr_bin);
-	return undef if length($result) == 0;
-	return $result;
+	return $self->lookup_raw($addr_bin);
 }
 
 =head2  lookup_raw - Lookup Address in raw format
@@ -285,7 +283,7 @@ nescessary.
 
 =cut 
 
-sub _lookup_raw {
+sub lookup_raw {
 	my ($self, $addr_bin) = @_;
 
 	if (length($addr_bin) == 4) {
@@ -306,14 +304,6 @@ sub _lookup_raw {
 	return undef;
 }
 
-sub lookup_raw {
-	my ($self, $addr_bin) = @_;
-
-	my $result = $self->_lookup_raw($addr_bin);
-	return undef if length($result) == 0;
-	return $result;
-}
-
 =head2  lookup_cache_raw - Lookup Address in raw format with cache
 
  
@@ -336,11 +326,10 @@ sub lookup_cache_raw {
 	my $result = $self->{CACHE}->{$addr_bin};
 
 	if (!defined($result)) {
-		$result = $self->_lookup_raw($addr_bin);
+		$result = $self->lookup_raw($addr_bin);
 		$self->{CACHE}->{$addr_bin} = $result;
 	}
 
-	return undef if ( ! defined($result) || length($result) == 0 );
 	return $result;
 }	
 
